/**
 * Base error type for batch processing
 * All errors thrown by major failures extend this base class
 */
declare class BaseBatchProcessingError extends Error {
    childErrors: Error[];
    msg: string;
    constructor(msg: string, childErrors: Error[]);
    /**
     * Generates a list of errors that were generated by the major failure
     * @returns Formatted string listing all the errors that occurred
     *
     * @example
     * When all batch records fail to be processed, this will generate a string like:
     * All records failed processing. 3 individual errors logged separately below.
     * ,Failed to process record.
     * ,Failed to process record.
     * ,Failed to process record.
     */
    formatErrors(parentErrorString: string): string;
}
/**
 * When all batch records failed to be processed
 */
declare class BatchProcessingError extends BaseBatchProcessingError {
    constructor(msg: string, childErrors: Error[]);
}
export { BaseBatchProcessingError, BatchProcessingError };
